@@ -12,11 +12,11 @@ Regexp::Pattern::License - Regular expressions for legal licenses
 
 =head1 VERSION
 
-Version v3.1.90
+Version v3.1.91
 
 =cut
 
-our $VERSION = version->declare("v3.1.90");
+our $VERSION = version->declare("v3.1.91");
 
 =head1 DESCRIPTION
 
@@ -129,7 +129,6 @@ $RE{adobe_2006} = {
 
 $RE{adobe_glyph} = {
 	name                                => 'Adobe-Glyph',
-	'name.alt.org.fedora'               => 'MIT',
 	'name.alt.org.fedora.web.mit.short' => 'AdobeGlyph',
 	'name.alt.org.spdx'                 => 'Adobe-Glyph',
 	'name.alt.org.tldr'                 => 'adobe-glyph-list-license',
@@ -190,15 +189,45 @@ $RE{agpl} = {
 
 =item * aladdin
 
+=item * aladdin_8
+
+=item * aladdin_9
+
 =cut
 
 $RE{aladdin} = {
 	name                  => 'Aladdin',
 	'name.alt.misc.short' => 'AFPL',
 	caption               => 'Aladdin Free Public License',
-	tags                  => ['type:unversioned'],
+	tags                  => ['type:versioned:decimal'],
 
 	'pat.alt.subject.name' => "$the?Aladdin Free Public License",
+	'pat.alt.subject.grant.scope.line.scope.sentence' =>
+		'under the terms of the Aladdin Free Public License',
+	'_pat.alt.subject.license.scope.line.scope.sentence' => [
+		'hereby grants to anyone the permission to apply',
+		'This License applies to the computer programs? known as',
+	],
+};
+
+$RE{aladdin_8} = {
+	name                    => 'Aladdin-8',
+	'name.alt.org.scancode' => 'afpl-8',
+	'name.alt.org.spdx'     => 'Aladdin',
+	'name.alt.org.debian'   => 'Aladdin-8',
+	caption                 => 'Aladdin Free Public License, Version 8',
+	tags                    => ['type:singleversion:aladdin'],
+};
+
+$RE{aladdin_9} = {
+	name                           => 'Aladdin-9',
+	'name.alt.org.scancode'        => 'afpl-9',
+	'name.alt.org.tldr.path.short' => 'aladdin',
+	caption                => 'Aladdin Free Public License, Version 9',
+	'caption.alt.org.tldr' => 'Aladdin Free Public License',
+	'iri.alt.archive.20130804020135' =>
+		'http://www.artifex.com/downloads/doc/Public.htm',
+	tags => ['type:singleversion:aladdin'],
 };
 
 =item * apache
@@ -277,7 +306,6 @@ $RE{artistic_2} = {
 
 $RE{bdwgc} = {
 	'name.alt.org.debian'               => 'MIT~Boehm',
-	'name.alt.org.fedora.web'           => 'MIT',
 	'name.alt.org.fedora.web.mit.short' => 'AnotherMinimalVariant',
 	caption                             => 'Boehm GC License',
 	'caption.alt.org.fedora.web.mit' =>
@@ -757,7 +785,6 @@ $RE{curl} = {
 
 $RE{dsdp} = {
 	name                             => 'DSDP',
-	'name.alt.org.fedora'            => 'MIT',
 	'name.alt.org.fedora.web'        => 'DSDP',
 	'name.alt.org.spdx'              => 'DSDP',
 	caption                          => 'DSDP License',
@@ -956,7 +983,6 @@ $RE{isc} = {
 
 $RE{icu} = {
 	name                             => 'ICU',
-	'name.alt.org.fedora'            => 'MIT',
 	caption                          => 'ICU License',
 	'caption.alt.org.fedora.web.mit' => 'Modern style (ICU Variant)',
 	tags                             => [ 'family:mit', 'type:unversioned' ],
@@ -1085,6 +1111,7 @@ $RE{llgpl} = {
 	'name.alt.org.tldr'    => 'lisp-lesser-general-public-license',
 	caption                => 'Lisp Lesser General Public License',
 	'caption.alt.org.tldr' => 'Lisp Lesser General Public License (LLGPL)',
+	iri                    => 'http://opensource.franz.com/preamble.html',
 	tags                   => ['type:unversioned'],
 
 	'_pat.alt.subject.name' => [
@@ -1113,7 +1140,6 @@ $RE{mit_advertising} = {
 
 $RE{mit_cmu} = {
 	name                             => 'MIT-CMU',
-	'name.alt.org.fedora'            => 'MIT',
 	'name.alt.org.spdx'              => 'MIT-CMU',
 	caption                          => 'CMU License',
 	'caption.alt.org.fedora.web.mit' => 'CMU Style',
@@ -1143,7 +1169,6 @@ END
 
 $RE{mit_cmu_warranty} = {
 	'name.alt.org.debian' => 'MIT-CMU~warranty',
-	'name.alt.org.fedora' => 'MIT',
 	caption               => 'CMU License (retain warranty disclaimer)',
 	'caption.alt.org.fedora.web.mit' => 'Standard ML of New Jersey Variant',
 	'caption.alt.org.fedora.web.mit.short' => 'MLton variant',
@@ -1167,7 +1192,6 @@ END
 
 $RE{mit_enna} = {
 	name                                => 'MIT-enna',
-	'name.alt.org.fedora'               => 'MIT',
 	'name.alt.org.fedora.web.mit.short' => 'enna',
 	'name.alt.org.spdx'                 => 'MIT-enna',
 	caption                             => 'enna License',
@@ -1187,7 +1211,6 @@ $RE{mit_enna} = {
 
 $RE{mit_feh} = {
 	name                                => 'MIT-feh',
-	'name.alt.org.fedora'               => 'MIT',
 	'name.alt.org.fedora.web.mit.short' => 'feh',
 	'name.alt.org.spdx'                 => 'MIT-feh',
 	caption                             => 'feh License',
@@ -1260,7 +1283,6 @@ $RE{mit_old} = {
 
 $RE{mit_oldstyle} = {
 	'name.alt.org.debian'            => 'MIT~oldstyle',
-	'name.alt.org.fedora'            => 'MIT',
 	caption                          => 'MIT (Old Style)',
 	'caption.alt.org.fedora.web.mit' => 'Old Style',
 	description                      => <<'END',
@@ -1280,7 +1302,6 @@ END
 
 $RE{mit_oldstyle_disclaimer} = {
 	'name.alt.org.debian'            => 'MIT~oldstyle~disclaimer',
-	'name.alt.org.fedora'            => 'MIT',
 	caption                          => 'MIT (Old Style, legal disclaimer)',
 	'caption.alt.org.fedora.web.mit' => 'Old Style with legal disclaimer',
 	tags                             => [ 'family:mit', 'type:unversioned' ],
@@ -1297,7 +1318,6 @@ $RE{mit_oldstyle_disclaimer} = {
 
 $RE{mit_oldstyle_permission} = {
 	'name.alt.org.debian' => 'MIT~oldstyle~permission',
-	'name.alt.org.fedora' => 'MIT',
 	'caption.alt.org.fedora.web.mit' =>
 		'Old Style (no advertising without permission)',
 	tags => [ 'family:mit', 'type:unversioned' ],
@@ -2043,7 +2063,7 @@ for my $id (@_OBJECTS) {
 		$RE{$id}{"name.$slug"}
 			||= $RE{$id}{$_} =~ s/\s/_/gr =~ s/\(/.28/gr =~ s/\)/.29/gr
 			and next CAPTION
-			if ( $slug and $slug =~ /\.alt\.org\.fedora\.web/ );
+			if ( $slug and $slug =~ /alt\.org\.fedora\.web/ );
 		if ( $org and $org eq 'tldr' ) {
 			$RE{$id}{"name.$slug"} ||= lc( $RE{$id}{$_} ) =~ s/\s/-/gr
 				if ( $slug eq 'alt.org.tldr' );
@@ -2176,7 +2196,7 @@ for my $id (@_OBJECTS) {
 				keys %{ $RE{$id} }
 		);
 		$RE{$id}{'_pat.alt.subject.grant.synth.caption'}
-			||= '(?:(?:[Ll]icensed|[Rr]eleased) under|(?:according to|under) the (?:conditions|terms) of) '
+			||= '(?:(?:[Ll]icensed|[Rr]eleased) under|(?:according to|as governed by|under) the (?:conditions|terms) of) '
 			. $caption =~ s/ - /${DD}/gr
 			if ($caption);
 	}
